from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def disconnect(vmanage, nmsId):
    """
    disconnect from mpd controller
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/disconnect/{nmsId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

def offboard(vmanage, nmsId):
    """
    offboard the mdp application
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard/{nmsId}"
    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class VPN(object):
    """
    Configuration - Policy VPN List Builder API
    
    Implements GET POST DEL PUT methods for PolicyVPNListBuilder endpoints

    """

    def __init__(vmanage, session, host, port):
        vmanage.host = host
        vmanage.port = port
        vmanage.client = HttpMethods.HttpClient(session=session)
    
    
    def get(vmanage):
        """
        Get policy lists
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/vpn"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def create(vmanage, policylist):
        """
        Create policy list
        
        Parameters:
        policylist:	Policy list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/vpn"
        response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
        return response


    def preview(vmanage, policylist):
        """
        Preview a policy list based on the policy list type
        
        Parameters:
        policylist:	Policy list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/vpn/preview"
        response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
        return response


    def previewById(vmanage, id):
        """
        Preview a specific policy list entry based on id provided
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/vpn/preview/{id}"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getListsById(vmanage, id):
        """
        Get a specific policy list based on the id
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/vpn/{id}"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def edit(vmanage, policylist, id):
        """
        Edit policy list entries for a specific type of policy list
        
        Parameters:
        policylist:	Policy list
		id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/vpn/{id}"
        response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policylist)
        return response


    def delete(vmanage, id):
        """
        Delete policy list entry for a specific type of policy list
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/vpn/{id}"
        response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





import json
from json.decoder import JSONDecodeError

class Parser(object):
    @staticmethod
    def parseResponse(response):
        if response.text != '':
            # check for invalid Json data
            try:
                raw_data = json.loads(response.text)
            except JSONDecodeError:
                error = {'error':"Invalid Json Data"}
                return error
            # check raw_data for key "data".
            # if the it doesn't exist, return raw_data
            if 'data' in raw_data:
                parsed_data = raw_data['data']
            else:
                parsed_data = raw_data
            return parsed_data
        else:
            # if response is an empty string, return it
            return response.text



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def add(vmanage, policy):
    """
    Add internal policy from vmanage
    
    Parameters:
    policy:	    Internal Policy
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/policies/mdpconfig"
    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policy)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def createFull(vmanage):
    """
    Create full topology
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/topology"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

def createDevice(vmanage, deviceId):
    """
    Create device topology
    
    Parameters:
    deviceId	 (array):	Device Id list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/topology/device?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

def createPhysical(vmanage, deviceId):
    """
    Create pysical topology
    
    Parameters:
    deviceId	 (array):	Device Id list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/topology/physical?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def get(vmanage):
    """
    Get policy lists
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/port"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

def create(vmanage, policylist):
    """
    Create policy list
    
    Parameters:
    policylist:	Policy list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/port"
    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
    return response

def preview(vmanage, policylist):
    """
    Preview a policy list based on the policy list type
    
    Parameters:
    policylist:	Policy list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/port/preview"
    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
    return response

def previewById(vmanage, id):
    """
    Preview a specific policy list entry based on id provided
    
    Parameters:
    id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/port/preview/{id}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

def getListsById(vmanage, id):
    """
    Get a specific policy list based on the id
    
    Parameters:
    id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/port/{id}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

def edit(vmanage, policylist, id):
    """
    Edit policy list entries for a specific type of policy list
    
    Parameters:
    policylist:	Policy list
	id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/port/{id}"
    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policylist)
    return response

def delete(vmanage, id):
    """
    Delete policy list entry for a specific type of policy list
    
    Parameters:
    id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/port/{id}"
    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def getSessionList(vmanage, deviceId):
    """
    Get security information from devices
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/security/information?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Connection(object):
    """
    Real-Time Monitoring - Cellular EIOLTE Connection Service API
    
    Implements GET POST DEL PUT methods for CellularEIOLTEConnectionService endpoints

    """

    def __init__(vmanage, session, host, port):
        vmanage.host = host
        vmanage.port = port
        vmanage.client = HttpMethods.HttpClient(session=session)
    
    
    def getConnInfo(vmanage, deviceId):
        """
        Get cellular connection info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellularEiolte/connections?deviceId={deviceId}"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getRadioInfo(vmanage, deviceId):
        """
        Get cellular radio info from device
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellularEiolte/radio?deviceId={deviceId}"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def pushConfigs(vmanage, config, nmsId):
    """
    Push device configs
    
    Parameters:
    config:	            Netconf configuration
	nmsId	 (string):	NMS Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/partner/wcm/netconf/{nmsId}"
    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, config)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def createReplicatorList(vmanage, deviceId):
    """
    Get replicator list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/replicator?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def createRpfList(vmanage, deviceId):
    """
    Get RPF list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/rpf?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def createTopologyList(vmanage, deviceId):
    """
    Get topology list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/topology?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def createPimTunnelList(vmanage, deviceId):
    """
    Get PIM tunnel from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/multicast/tunnel?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def checkGivenIpList(vmanage, devicedetail):
    """
    Block IP based on list
    
    Parameters:
    devicedetail:	Device detail
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/software/compliance/ip/origin/check"
    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, devicedetail)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Server(object):
    """
    Monitoring - Server Info API
    
    Implements GET POST DEL PUT methods for ServerInfo endpoints

    """

    def __init__(vmanage, session, host, port):
        vmanage.client = HttpMethods.HttpClient(session=session)
        vmanage.host = host
        vmanage.port = port
    
    
    def createServerInfo(vmanage):
        """
        Get Server info
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/server/info"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def preview(vmanage, policyassembly):
    """
    Get policy assembly preview
    
    Parameters:
    policyassembly:	Policy assembly
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/assembly/vedge"
    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policyassembly)
    return response

def previewById(vmanage, id):
    """
    Get policy assembly preview
    
    Parameters:
    id	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/assembly/vedge/{id}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def getsupportedLocales(vmanage):
    """
    Get Supported locales
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/localization/supportedLocales"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class EIOLTE(object):
    """
    Monitoring - Cellular-EIOLTE API
    
    Implements GET POST DEL PUT methods for EIOLTE endpoints

    """

    def __init__(vmanage, session, host, port):
        vmanage.client  = HttpMethods.HttpClient(session=session)
        vmanage.host    = host
        vmanage.port    = port
        vmanage.builder = Builder()
    
    def getStatDataRawData(vmanage, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        query_string = vmanage.builder.generateQuery(query)
        endpoint     = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte?query={query_string}"
        response     = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(vmanage, statsquerystring):
        """
        Get stats raw data
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte"
        response = vmanage.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getAggregationDataByQuery(vmanage, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        query_string = vmanage.builder.generateQuery(query)
        endpoint     = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/aggregation?query={query_string}"
        response     = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(vmanage, statsquerystring):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/aggregation"
        response = vmanage.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getPostAggregationAppDataByQuery(vmanage, statsquerystring):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/app-agg/aggregation"
        response = vmanage.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getStatDataRawDataAsCSV(vmanage, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        query_string = vmanage.builder.generateQuery(query)
        endpoint     = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/csv?query={query_string}"
        response     = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(vmanage, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        query_string = vmanage.builder.generateQuery(query)
        endpoint     = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/doccount?query={query_string}"
        response     = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(vmanage, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/doccount"
        response = vmanage.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataFields(vmanage):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/fields"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(vmanage, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        query_string = vmanage.builder.generateQuery(query)
        endpoint     = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/page?query={query_string}&scrollId={scrollId}&count={count}"
        response     = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(vmanage, statsquerystring, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        statsquerystring:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/page?scrollId={scrollId}&count={count}"
        response = vmanage.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getStatQueryFields(vmanage):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/statistics/eiolte/query/fields"
        response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def getSigDataCenterList(vmanage, type):
    """
    Get list of data centers for zscaler or umbrella
    
    Parameters:
    type	 (string):	Provider type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sig/datacenters/{type}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response



import os
for module in os.listdir(os.path.dirname(__file__)):
    if module != '__init__.py' and module[:-3] == ".py":
        module = module[:-3]
        from py_viptela.api.cert import module
    elif module != '__init__.py' and module[:-3] != ".py":
        from py_viptela.api.cert import module
del module


from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def getCloudConnector(vmanage):
    """
    Get SD_AVC Cloud Connector Config
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def disableCloudConnector(vmanage, payload):
    """
    Disable SD_AVC Cloud Connector
    
    Parameters:
    payload:	Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector"
    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, payload)
    return response
def enableCloudConnector(vmanage, payload):
    """
    Enable SD_AVC Cloud Connector
    
    Parameters:
    payload:	Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector"
    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
    return response
def getCloudConnectorStatus(vmanage):
    """
    Get SD_AVC Cloud Connector Status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sdavc/cloudconnector/status"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response



from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def onboardMDP(vmanage, onboard):
    """
    Start MDP onboarding operation
    
    Parameters:
    onboard:	Onboard
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard"
    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, onboard)
    return response

def getOnboardStatus(vmanage):
    """
    Get MDP onboarding status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard/status"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

def updateOnboardingPayload(vmanage, onboard, nmsId):
    """
    update MDP onboarding document
    
    Parameters:
    onboard:	Onboard
	Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/mdp/onboard/{nmsId}"
    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, onboard)
    return response
